@@ -3,69 +3,23 @@
 Adapter sqlwrapper: Schnittstelle zur SQL-Datenbank
 """
 
-from visaplan.plone.base import Base, Interface
+from __future__ import absolute_import
+from six.moves import range
+
+from visaplan.plone.base import Base
 from exceptions import NotImplementedError
 from App.config import getConfiguration
 
 from visaplan.plone.tools.log import getLogSupport
 logger, debug_active, DEBUG = getLogSupport(fn=__file__,
                                             defaultFromDevMode=False)
+from .interfaces import ISQLWrapper
 from .utils import (check_name, generate_dicts, replace_names,
         make_where_mask,
         make_transaction_cmd, make_returning_clause,
         )
 
 
-class ISQLWrapper(Interface):
-
-    """Interface für Standard-SQL-Befehle."""
-
-    def insert(self, table, dict_of_values,
-               returning=None, commit=None, transform=None):
-        """
-        Speichere die Werte aus dem Dictionary in die Tabelle.
-        Keys aus dem Dictionary müssen mit den Tabellenfeldern
-        übereinstimmen.
-        Es werden nur Werte für eine Zeile akzeptiert.
-
-        table -- Name der Tabelle
-        dict_of_values -- dict {Feldname: Wert}
-        returning -- z. B. 'id'; PostgreSQL 9.1+
-        commit -- soll dem SQL-Befehl ein COMMIT; angehängt werden?
-        transform -- ignoriert; nicht mehr verwenden
-        """
-
-    def update(self, table, dict_of_values, where=None, query_data={},
-               returning=None,
-               commit=None):
-        """
-            Macht ein Update auf eine Tabelle.
-            Schmeißt fehler zurück.
-        """
-
-    def delete(self, table, where=None, query_data=None,
-               returning=None,
-               commit=None):
-        """
-            Löscht Eintr(ä)ag(e) aus der Datenbank.
-            Ohne Id oder WHERE-Clause werden alle Inhalte gelöscht.
-        """
-
-    def select(self, table, fields=None, where=None,
-               query_data=None, maxrows=None):
-        """
-        Hole Werte aus einer einzelnen Tabelle oder Sicht der SQL-Datenbank.
-
-        table -- Name der Tabelle oder Sicht
-        fields -- Namen der Felder (optional; Standardwert: '*')
-        where -- ein vorformuliertes WHERE-Kriterium, mit Platzhaltern
-                 für die Werte (Python-Dictionary-Syntax);
-                 ggf. aus <query_data> generiert
-        query_data -- ein Dictionary mit den Abfragedaten
-        maxrows - weitergereicht an self.db.query
-        """
-
-
 class Adapter(Base):
     """Klasse für Standard-SQL-Befehle."""
 
@@ -154,7 +108,7 @@ class Adapter(Base):
         commit -- soll dem SQL-Befehl ein COMMIT; angehängt werden?
         transform -- ignoriert; nicht mehr verwenden
         """
-        keys = dict_of_values.keys()
+        keys = list(dict_of_values.keys())
         rows = ', '.join(keys)
         values = ', '.join([key.join(('%(', ')s'))
                             for key in keys
@@ -196,7 +150,7 @@ class Adapter(Base):
         commit -- soll dem SQL-Befehl ein COMMIT; angehängt werden?
         """
         raise NotImplemented
-        keys = dict_of_values.keys()
+        keys = list(dict_of_values.keys())
         rows = ', '.join(keys)
         values = ', '.join([key.join(('%(', ')s'))
                             for key in keys
@@ -259,7 +213,7 @@ class Adapter(Base):
         <commit> ist nicht getestet; <returning> wird daher am besten
         mit dem Kontext-Manager-Protokoll verwendet!
         """
-        keys = dict_of_values.keys()
+        keys = list(dict_of_values.keys())
         qset = ', '.join([''.join((key, '=%(', key, ')s'))
                           for key in keys
                           ])
